@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObject.cpp,v 1.13 2006/09/15 05:30:33 vkurland Exp $
+  $Id: FWObject.cpp,v 1.14 2006/09/20 15:38:00 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -352,8 +352,7 @@ FWObject& FWObject::shallowDuplicate(const FWObject *x, bool preserve_id) throw(
 	setId(id);
 
     if (dbroot==NULL) setRoot(x->getRoot());
-
-    getRoot()->addToIndex(this);
+    if (dbroot!=NULL) FWObjectDatabase::cast(dbroot)->addToIndex(this);
 
     setDirty(true);
     return *this;
